import React, { useState } from 'react'
import { Inertia } from '@inertiajs/inertia'
import { InertiaLink, usePage } from '@inertiajs/inertia-react'
import Layout from '@/Shared/Layout'
import Button from '@/Shared/Button'
import SelectInput from '@/Shared/SelectInput'
import TextInput from '@/Shared/TextInput'

const FormsCreateForm = data => {
  const { availableForms, errors } = usePage()

  const [values, setValues] = useState({
    name: '',
    model: availableForms,
    type: '',
  })

  function handleChange(e) {
    const key = e.target.name
    const value = e.target.value
    setValues(values => ({
      ...values,
      [key]: value,
    }))
  }

  function handleSubmit(e) {
    e.preventDefault()
    Inertia.post(route('eventpal.forms.store'), values)
  }

  return (
    <div>
      <form onSubmit={handleSubmit}>
        <div className='form-panel'>
          <div>
            <TextInput
              className='pb-3'
              label='Name'
              name='name'
              errors={errors.name}
              value={values.name}
              onChange={handleChange}
            />
          </div>
          <div>
            <SelectInput
              className='pb-3'
              label='Form / Data to Manage'
              name='model'
              errors={errors.model}
              value={values.model}
              onChange={handleChange}
            >
              <option value=''>Select...</option>
              {Object.entries(availableForms).map(([key, value]) => (
                <option key={key} value={value}>
                  {key}
                </option>
              ))}
            </SelectInput>
          </div>
          <div>
            <SelectInput
              className='pb-3'
              label='Type'
              name='type'
              errors={errors.type}
              value={values.type}
              onChange={handleChange}
            >
              <option value='general'>General Form</option>
              <option value='qna'>Q&A Form</option>
            </SelectInput>
          </div>
        </div>
        <div className='page-actions'>
          <InertiaLink
            className='btn btn-light tw-float-left'
            href={route('eventpal.forms.index')}
          >
            <span>
              <i className='fas fa-chevron-left' />
              Back to Forms list
            </span>
          </InertiaLink>
          <Button
            type='submit'
            value='Submit'
            icon='fas fa-check'
            className='btn btn-dark tw-float-right'
          />
        </div>
      </form>
    </div>
  )
}

// eslint-disable-next-line react/display-name
FormsCreateForm.layout = form => (
  <Layout area='Forms' title='Create Form'>
    {form}
  </Layout>
)

export default FormsCreateForm
