import React, { useState } from 'react'
import { Inertia } from '@inertiajs/inertia'
import { InertiaLink, usePage } from '@inertiajs/inertia-react'
import Layout from '@/Shared/Layout'
import Button from '@/Shared/Button'
import TextInput from '@/Shared/TextInput'
import TextAreaInput from '../../../../Shared/TextAreaInput'

const FormsCreateQNAForm = data => {
  const { form, errors } = usePage()

  const [values, setValues] = useState({
    registration_id: '',
    speaker: '',
    question: '',
  })

  function handleChange(e) {
    const key = e.target.name
    const value = e.target.value
    setValues(values => ({
      ...values,
      [key]: value,
    }))
  }

  function handleSubmit(e) {
    e.preventDefault()
    Inertia.post(route('eventpal.forms.records.store', form), values)
  }

  return (
    <div>
      <form onSubmit={handleSubmit}>
        <div className='form-panel'>
          <div>
            <TextInput
              className='pb-3'
              label='Registration ID'
              name='registration_id'
              errors={errors.registration_id}
              value={values.registration_id}
              onChange={handleChange}
            />
          </div>
          <div>
            <TextInput
              className='pb-3'
              label='Speaker'
              name='speaker'
              errors={errors.speaker}
              value={values.speaker}
              onChange={handleChange}
            />
          </div>
          <div>
            <TextAreaInput
              className='pb-3 resize-none'
              label='Question'
              name='question'
              errors={errors.question}
              value={values.question}
              onChange={handleChange}
            />
          </div>
        </div>
        <div className='page-actions'>
          <InertiaLink
            className='btn btn-light tw-float-left'
            href={route('eventpal.forms.records.index', form)}
          >
            <span>
              <i className='fas fa-chevron-left' />
              Back to Record list
            </span>
          </InertiaLink>
          <Button
            type='submit'
            value='Submit'
            icon='fas fa-check'
            className='btn btn-dark tw-float-right'
          />
        </div>
      </form>
    </div>
  )
}

// eslint-disable-next-line react/display-name
FormsCreateQNAForm.layout = form => (
  <Layout area='Manage - Q&A' title='Create Form'>
    {form}
  </Layout>
)

export default FormsCreateQNAForm
