import React, { useState } from 'react'
import { Inertia } from '@inertiajs/inertia'
import { InertiaLink, usePage } from '@inertiajs/inertia-react'
import Layout from '@/Shared/Layout'
import Button from '@/Shared/Button'
import Checkbox from '@/Shared/Checkbox'
import SelectInput from '@/Shared/SelectInput'
import TextInput from '@/Shared/TextInput'
import TextAreaInput from '@/Shared/TextAreaInput'
import ReactSelect from '@/Shared/ReactSelect'

const NotificationsCreateForm = data => {
  const { events, statuses, errors } = usePage()
  const userSegments = data.allSegments.map(segment => {
    return {
      value: segment.id,
      label: segment.name,
    }
  })

  const [values, setValues] = useState({
    event: '',
    status: 'DRAFT',
    title: '',
    message: '',
    sendAt: '',
    sendNow: 0,
    segments: [],
  })

  function handleChange(e) {
    const key = e.target.name
    const value = e.target.value
    setValues(values => ({
      ...values,
      [key]: value,
    }))

    if (key === 'sendNow' && value === 1) {
      setValues(values => ({
        ...values,
        sendAt: '',
      }))
    }
  }

  function handleSubmit(e) {
    e.preventDefault()
    Inertia.post(route('eventpal.notifications.store'), values)
  }

  return (
    <div>
      <form onSubmit={handleSubmit}>
        <div className='form-panel'>
          <div className='form-group'>
            <SelectInput
              className='pb-3'
              label='Event'
              name='event'
              errors={errors.event}
              value={values.event}
              onChange={handleChange}
            >
              <option value=''>Select...</option>
              {events.map((event, index) => (
                <option key={index} value={event.id}>
                  {event.title}
                </option>
              ))}
            </SelectInput>
          </div>
          <div className='form-group'>
            <ReactSelect
              className='pb-3'
              label='Segments'
              name='segments'
              helpText='If no segments are selected, the notification will send to all devices for the event.'
              options={userSegments}
              errors={errors.segments}
              selectedOptions={values.segments}
              onChange={handleChange}
              isMultiple={true}
            />
          </div>
          <div className='form-group'>
            <TextInput
              className='pb-3'
              label='Title'
              name='title'
              errors={errors.title}
              value={values.title}
              onChange={handleChange}
            />
          </div>
          <div className='form-group'>
            <TextAreaInput
              className='pb-3 resize-none'
              label='Message'
              name='message'
              errors={errors.message}
              value={values.message}
              onChange={handleChange}
            />
          </div>
          <div className='form-group'>
            <SelectInput
              className='pb-3'
              label='Status'
              name='status'
              errors={errors.status}
              value={values.status}
              onChange={handleChange}
            >
              <option value=''>Select...</option>
              {statuses.map((status, index) => (
                <option key={index} value={status.value}>
                  {status.label}
                </option>
              ))}
            </SelectInput>
          </div>
          <div className='form-group'>
            <TextInput
              className='pb-3'
              label='Send at'
              name='sendAt'
              helpText='Enter a timestamp in the following format: DD-MM-YYYY HH:MM:SS'
              errors={errors.sendAt}
              value={values.sendAt}
              onChange={handleChange}
              readOnly={!!values.sendNow}
            />
          </div>
          <div className='form-group'>
            <Checkbox
              className='pb-3'
              label='Send now'
              name='sendNow'
              errors={errors.sendNow}
              value={values.sendNow}
              onChange={handleChange}
            />
          </div>
        </div>
        <div className='page-actions'>
          <InertiaLink
            className='btn btn-light tw-float-left'
            href={route('eventpal.notifications.index')}
          >
            <span>
              <i className='fas fa-chevron-left' />
              Back to notifications list
            </span>
          </InertiaLink>
          <Button
            type='submit'
            value='Submit'
            icon='fas fa-check'
            className='btn btn-dark tw-float-right'
          />
        </div>
      </form>
    </div>
  )
}

// eslint-disable-next-line react/display-name
NotificationsCreateForm.layout = notification => (
  <Layout area='Notifications' title='Create Notification'>
    {notification}
  </Layout>
)

export default NotificationsCreateForm
