import React from 'react'
import { InertiaLink } from '@inertiajs/inertia-react'
import Layout from '@/Shared/Layout'

const Notifications = data => {
  const notifications = data.notifications

  return (
    <div className='table-panel'>
      <div className='table-panel__header'>
        <InertiaLink
          className='btn btn-dark'
          href='/eventpal/notifications/create'
        >
          <i className='fas fa-plus' />
          Create / Send Notification
        </InertiaLink>
      </div>
      <div className='table-panel__table'>
        <table className='table table-striped'>
          <thead>
            <tr>
              <th>#</th>
              <th>Event</th>
              <th>Status</th>
              <th>Title</th>
              <th>Message</th>
              <th>Send at</th>
              <th>Sent</th>
              <th>Total Sent</th>
              <th>Actions</th>
            </tr>
          </thead>
          <tbody>
            {notifications.map(notification => (
              <tr key={notification.id}>
                <td>{notification.id}</td>
                <td>{notification.eventTitle}</td>
                <td>{notification.status}</td>
                <td>{notification.title}</td>
                <td>{notification.message}</td>
                <td>
                  {notification.sendAt !== null
                    ? notification.sendAt
                    : 'Not scheduled'}
                </td>
                <td>
                  {notification.sent === true ? (
                    <span className='badge badge-success'>&#10003;</span>
                  ) : (
                    <span className='badge badge-danger'>X</span>
                  )}
                </td>
                <td>
                  {notification.totalSent > 0 ? notification.totalSent : 'None'}
                </td>
                <td>
                  <InertiaLink
                    className='action-button'
                    href={route('eventpal.notifications.edit', notification)}
                    title='Edit notification'
                  >
                    <span>
                      <i className='fas fa-pencil-alt fa-lg' />
                    </span>
                  </InertiaLink>

                  <InertiaLink
                    className='action-button danger'
                    href={`/eventpal/notifications/${notification.id}`} // TODO: Update to form / add in modal
                    title='Delete notification'
                    method='delete'
                  >
                    <span>
                      <i className='fas fa-trash-alt fa-lg' />
                    </span>
                  </InertiaLink>
                </td>
              </tr>
            ))}
            {notifications.length === 0 && (
              <tr>
                <td className='no-results' colSpan='9'>
                  No notifications found
                </td>
              </tr>
            )}
          </tbody>
        </table>
      </div>
    </div>
  )
}

// eslint-disable-next-line react/display-name
Notifications.layout = notification => (
  <Layout title='Notifications'>{notification}</Layout>
)

export default Notifications
