import React, { useState } from 'react'
import { Inertia } from '@inertiajs/inertia'
import { InertiaLink, usePage } from '@inertiajs/inertia-react'
import Layout from '@/Shared/Layout'
import TextInput from '@/Shared/TextInput'
import TextAreaInput from '@/Shared/TextAreaInput'
import Button from '@/Shared/Button'

const SpeakersEditForm = () => {
  const { speaker, errors } = usePage()

  const [values, setValues] = useState({
    name: speaker.name || '',
    company: speaker.company || '',
    jobTitle: speaker.jobTitle || '',
    bio: speaker.bio || '',
  })

  function handleChange(e) {
    const key = e.target.name
    const value = e.target.value
    setValues(values => ({
      ...values,
      [key]: value,
    }))
  }

  function handleSubmit(e) {
    e.preventDefault()
    Inertia.put(route('eventpal.speakers.update', speaker), values)
  }

  return (
    <div>
      <form onSubmit={handleSubmit}>
        <div className='form-panel'>
          <div className=''>
            <TextInput
              className='mb-4'
              label='Name'
              name='name'
              errors={errors.name}
              value={values.name}
              onChange={handleChange}
            />
            <TextInput
              className='pb-3'
              label='Company'
              name='company'
              errors={errors.company}
              value={values.company}
              onChange={handleChange}
            />
            <TextInput
              className='pb-3'
              label='Job title'
              name='jobTitle'
              type='text'
              errors={errors.jobTitle}
              value={values.jobTitle}
              onChange={handleChange}
            />
            <TextAreaInput
              className='pb-3'
              label='Biography'
              name='bio'
              type='text'
              errors={errors.bio}
              value={values.bio}
              onChange={handleChange}
            />
          </div>
          <div className=''>
            <Button
              type='submit'
              value='Submit'
              icon='fas fa-check'
              className='btn btn-dark'
            />
          </div>
        </div>
        <div className='page-actions'>
          <InertiaLink
            className='btn btn-light tw-float-left'
            href={route('eventpal.speakers.index')}
          >
            <span>
              <i className='fas fa-chevron-left' />
              Back to Speakers list
            </span>
          </InertiaLink>
          <Button
            type='submit'
            value='Submit'
            icon='fas fa-check'
            className='btn btn-dark tw-float-right'
          />
        </div>
      </form>
    </div>
  )
}

// eslint-disable-next-line react/display-name
SpeakersEditForm.layout = page => <Layout title='Edit Speaker'>{page}</Layout>

export default SpeakersEditForm
