import React from 'react'
import { InertiaLink } from '@inertiajs/inertia-react'
import Layout from '@/Shared/Layout'

const Speakers = data => {
  const speakers = data.speakers
  const bioLength = 100

  return (
    <div className='table-panel'>
      <div className='table-panel__header'>
        <InertiaLink
          className='btn btn-dark'
          href={route('eventpal.speakers.create')}
        >
          <span>
            <i className='fas fa-plus' />
            Create speaker
          </span>
        </InertiaLink>
      </div>

      <div className='table-panel__table'>
        <table className='table table-striped'>
          <thead>
            <tr>
              <th>#</th>
              <th>Name</th>
              <th>Company</th>
              <th>Job title</th>
              <th>Bio</th>
              <th>Actions</th>
            </tr>
          </thead>
          <tbody>
            {speakers.map(speaker => (
              <tr key={speaker.id}>
                <td>{speaker.id}</td>
                <td>{speaker.name}</td>
                <td>{speaker.company}</td>
                <td>{speaker.jobTitle}</td>
                <td>
                  {speaker.bio.length > bioLength
                    ? speaker.bio.substring(0, bioLength - 3) + '...'
                    : speaker.bio.substring(0, bioLength)}
                </td>
                <td>
                  <InertiaLink
                    className='action-button'
                    href={route('eventpal.speakers.edit', speaker)}
                    title='Edit speaker'
                  >
                    <span>
                      <i className='fas fa-pencil-alt fa-lg' />
                    </span>
                  </InertiaLink>

                  <InertiaLink
                    className='action-button danger'
                    href={route('eventpal.speakers.delete', speaker)}
                    title='Delete speaker'
                    method='delete'
                  >
                    <span>
                      <i className='fas fa-trash-alt fa-lg' />
                    </span>
                  </InertiaLink>
                </td>
              </tr>
            ))}
            {speakers.length === 0 && (
              <tr>
                <td className='no-results' colSpan='4'>
                  No speakers found
                </td>
              </tr>
            )}
          </tbody>
        </table>
      </div>
    </div>
  )
}

// eslint-disable-next-line react/display-name
Speakers.layout = page => (
  <Layout area='Speakers' title='Speaker list'>
    {page}
  </Layout>
)

export default Speakers
