import React from 'react'
import PropTypes from 'prop-types'

export default function TextAreaInput({
  label,
  name,
  helpText,
  className,
  errors = [],
  ...props
}) {
  return (
    <div className={`tw-mb-8 input-group ${className}`}>
      {label && <label htmlFor={name}>{label}</label>}
      <textarea
        id={name}
        name={name}
        {...props}
        className={`tw-h-24 tw-border-2 tw-border-brand-border tw-w-full tw-p-3 tw-leading-tight focus:outline-none focus:shadow-outline ${
          errors.length ? 'error' : ''
        }`}
      />
      {errors && <div className='input-group__form-error'>{errors[0]}</div>}
      {helpText && <div className='input-group__help-text'>{helpText}</div>}
    </div>
  )
}

TextAreaInput.propTypes = {
  className: PropTypes.string,
  errors: PropTypes.array,
  helpText: PropTypes.string,
  label: PropTypes.string,
  name: PropTypes.string.isRequired,
}
