<?php

namespace Drp\EventPalAdmin\Http\Controllers\Forms;

use Drp\EventPalAdmin\Http\Controllers\Controller;
use Drp\EventPalAdmin\Http\Models\Form;
use Drp\EventPalAdmin\Http\Requests\FormRequest;
use Illuminate\Http\RedirectResponse;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Facades\Session;
use Inertia\Inertia;
use Inertia\Response;

class FormController extends Controller
{
    public function index(): Response
    {
        $forms = Form::all();

        return Inertia::render('Forms/Index', compact('forms'));
    }

    public function create(): Response
    {
        return Inertia::render('Forms/Create', [
            'availableForms' => config('eventpal-admin.forms'),
        ]);
    }

    public function store(FormRequest $request): RedirectResponse
    {
        Form::create($request->all());

        Session::flash('success', 'Form Configured');

        return Redirect::route('eventpal.forms.index');
    }

    public function edit(Form $form): Response //phpcs: ignore
    {
        $availableForms = config('eventpal-admin.forms');

        return Inertia::render('Forms/Edit', compact('availableForms', 'form'));
    }

    public function update(FormRequest $request, Form $form): RedirectResponse
    {
        $form->update($request->all());

        Session::flash('success', 'Form Updated');

        return Redirect::route('eventpal.forms.index');
    }
}
